@@ -250,7 +250,8 @@ static codec_capabilities_t *gst_avdtp_find_caps(GstAvdtpSink *sink,
 	int bytes_left = rsp->h.length - sizeof(*rsp);
 
 	while (bytes_left > 0) {
-		if (codec->type == codec_type)
+		if ((codec->type == codec_type) &&
+				!(codec->lock & BT_WRITE_LOCK))
 			break;
 
 		bytes_left -= codec->length;
@@ -273,7 +274,7 @@ static gboolean gst_avdtp_sink_init_sbc_pkt_conf(GstAvdtpSink *sink,
 	gint rate, subbands, blocks;
 	GstStructure *structure = gst_caps_get_structure(caps, 0);
 
-	cfg = (void *) gst_avdtp_find_caps(sink, BT_A2DP_CODEC_SBC);
+	cfg = (void *) gst_avdtp_find_caps(sink, BT_A2DP_SBC_SINK);
 	name = gst_structure_get_name(structure);
 
 	if (!(IS_SBC(name))) {
@@ -429,14 +430,11 @@ static gboolean gst_avdtp_sink_conf_recv_stream_fd(
 static gboolean server_callback(GIOChannel *chan,
 					GIOCondition cond, gpointer data)
 {
-	GstAvdtpSink *sink;
-
 	if (cond & G_IO_HUP || cond & G_IO_NVAL)
 		return FALSE;
-	else if (cond & G_IO_ERR) {
-		sink = GST_AVDTP_SINK(data);
-		GST_WARNING_OBJECT(sink, "Untreated callback G_IO_ERR");
-	}
+	else if (cond & G_IO_ERR)
+		GST_WARNING_OBJECT(GST_AVDTP_SINK(data),
+					"Untreated callback G_IO_ERR");
 
 	return TRUE;
 }
@@ -741,8 +739,8 @@ static gboolean gst_avdtp_sink_update_caps(GstAvdtpSink *self)
 
 	GST_LOG_OBJECT(self, "updating device caps");
 
-	sbc = (void *) gst_avdtp_find_caps(self, BT_A2DP_CODEC_SBC);
-	mpeg = (void *) gst_avdtp_find_caps(self, BT_A2DP_CODEC_MPEG12);
+	sbc = (void *) gst_avdtp_find_caps(self, BT_A2DP_SBC_SINK);
+	mpeg = (void *) gst_avdtp_find_caps(self, BT_A2DP_MPEG12_SINK);
 
 	sbc_structure = gst_avdtp_sink_parse_sbc_caps(self, sbc);
 	mpeg_structure = gst_avdtp_sink_parse_mpeg_caps(self, mpeg);
@@ -775,7 +773,7 @@ static gboolean gst_avdtp_sink_get_capabilities(GstAvdtpSink *self)
 
 	if (self->device == NULL)
 		return FALSE;
-	strncpy(req->device, self->device, 18);
+	strncpy(req->destination, self->device, 18);
 	if (self->autoconnect)
 		req->flags |= BT_FLAG_AUTOCONNECT;
 
@@ -891,7 +889,6 @@ static gboolean gst_avdtp_sink_start(GstBaseSink *basesink)
 					G_IO_NVAL, server_callback, self);
 
 	self->data = g_new0(struct bluetooth_data, 1);
-	memset(self->data, 0, sizeof(struct bluetooth_data));
 
 	self->stream = NULL;
 	self->stream_caps = NULL;
@@ -1036,34 +1033,69 @@ static gboolean gst_avdtp_sink_configure(GstAvdtpSink *self,
 			GstCaps *caps)
 {
 	gchar buf[BT_SUGGESTED_BUFFER_SIZE];
+	struct bt_open_req *open_req = (void *) buf;
+	struct bt_open_rsp *open_rsp = (void *) buf;
 	struct bt_set_configuration_req *req = (void *) buf;
 	struct bt_set_configuration_rsp *rsp = (void *) buf;
 	gboolean ret;
 	GIOError io_error;
 	gchar *temp;
 	GstStructure *structure;
+	codec_capabilities_t *codec = NULL;
 
 	temp = gst_caps_to_string(caps);
 	GST_DEBUG_OBJECT(self, "configuring device with caps: %s", temp);
 	g_free(temp);
 
+	structure = gst_caps_get_structure(caps, 0);
+
+	if (gst_structure_has_name(structure, "audio/x-sbc"))
+		codec = (void *) gst_avdtp_find_caps(self, BT_A2DP_SBC_SINK);
+	else if (gst_structure_has_name(structure, "audio/mpeg"))
+		codec = (void *) gst_avdtp_find_caps(self, BT_A2DP_MPEG12_SINK);
+
+	if (codec == NULL) {
+		GST_ERROR_OBJECT(self, "Couldn't parse caps "
+				"to packet configuration");
+		return FALSE;
+	}
+
+	memset(req, 0, BT_SUGGESTED_BUFFER_SIZE);
+	open_req->h.type = BT_REQUEST;
+	open_req->h.name = BT_OPEN;
+	open_req->h.length = sizeof(*open_req);
+
+	strncpy(open_req->destination, self->device, 18);
+	open_req->seid = codec->seid;
+	open_req->lock = BT_WRITE_LOCK;
+
+	io_error = gst_avdtp_sink_audioservice_send(self, &open_req->h);
+	if (io_error != G_IO_ERROR_NONE) {
+		GST_ERROR_OBJECT(self, "Error ocurred while sending "
+					"open packet");
+		return FALSE;
+	}
+
+	open_rsp->h.length = sizeof(*open_rsp);
+	io_error = gst_avdtp_sink_audioservice_expect(self,
+			&open_rsp->h, BT_OPEN);
+	if (io_error != G_IO_ERROR_NONE) {
+		GST_ERROR_OBJECT(self, "Error while receiving device "
+					"confirmation");
+		return FALSE;
+	}
+
 	memset(req, 0, sizeof(buf));
 	req->h.type = BT_REQUEST;
 	req->h.name = BT_SET_CONFIGURATION;
 	req->h.length = sizeof(*req);
 
-	req->access_mode = BT_CAPABILITIES_ACCESS_MODE_WRITE;
-	strncpy(req->device, self->device, 18);
-	structure = gst_caps_get_structure(caps, 0);
-
-	if (gst_structure_has_name(structure, "audio/x-sbc"))
+	if (codec->type == BT_A2DP_SBC_SINK)
 		ret = gst_avdtp_sink_init_sbc_pkt_conf(self, caps,
 				(void *) &req->codec);
-	else if (gst_structure_has_name(structure, "audio/mpeg"))
+	else
 		ret = gst_avdtp_sink_init_mp3_pkt_conf(self, caps,
 				(void *) &req->codec);
-	else
-		ret = FALSE;
 
 	if (!ret) {
 		GST_ERROR_OBJECT(self, "Couldn't parse caps "
